#

##

##

    	businesses
    		# businesses
    			# merchants
    			# creatures
    			# organisms
    			# electors..

    		# populace
    			# individuals
    			# peers
    			# connections

    		# wallets
    			# safes
    			# vaults
    			# citadels
    			# cores

    	objectives ranked

    		[ ]

    	possibilities

    		[ ] Businesses propose to the consensus to be accepted.

    				{
    					"ID": "",
    					"passport": {},
    					"bioauth": {}
    				}

    			[ ] How to gift kids money and votes?

    					most kids don't have IDs or passports